@@ -1,9 +1,6 @@
 from aif360.algorithms.preprocessing import Reweighing
 from aif360.datasets.binary_label_dataset import BinaryLabelDataset
-
-def generate_binary_label_dataset(df, label, protected_attribute, favorable_label, unfavorable_label):
-    return BinaryLabelDataset(unfavorable_label, favorable_label, df=df, label_names=[label], protected_attribute_names=[protected_attribute])
-
+from MLFairnessPipeline.Utilities import generate_binary_label_dataset
 
 def Preprocessing(dataset, label, unprivileged_groups, privileged_groups, protected_attribute, favorable_label, unfavorable_label):
     binary_dataset = generate_binary_label_dataset(dataset, label, protected_attribute, favorable_label, unfavorable_label)
